antares.apps.terminal package — Antares 0.0.2 documentation

# antares.apps.terminal package

## Subpackages

- antares.apps.terminal.api package
  - Submodules
  - antares.apps.terminal.api.api_remote_terminal_view module
  - Module contents
- antares.apps.terminal.migrations package
  - Submodules
  - antares.apps.terminal.migrations.0001_initial module
  - antares.apps.terminal.migrations.0002_terminallog_author module
  - Module contents
- antares.apps.terminal.models package
  - Submodules
  - antares.apps.terminal.models.terminal_log module
  - Module contents
- antares.apps.terminal.service package
  - Module contents
- antares.apps.terminal.tests package
  - Submodules
  - antares.apps.terminal.tests.remote_terminal_test module
  - Module contents
- antares.apps.terminal.views package
  - Submodules
  - antares.apps.terminal.views.remote_terminal_view module
  - Module contents

## Submodules

## antares.apps.terminal.admin module

## antares.apps.terminal.apps module

class `antares.apps.terminal.apps.` `TerminalConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'terminal'

## antares.apps.terminal.urls module

## Module contents